<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-plan?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// P
	'plan_description' => 'Tiu kromprogramo plibonigas la privatspacan paĝon „Mapo de la retejo“ per malfaldebla strukturo kaj filtrilo pri statuso de artikoloj.',
	'plan_nom' => 'Mapo de la retejo en la privata spaco',
	'plan_slogan' => 'Plibonigas la mapon de la retejo en la privata spaco',
];
